.. highlight:: sh

Installation
============

The quickest way to install is to type::

    $ pip install scipydirect

More detailed instructions follow. To install scipydirect you will need the following prerequisites:

* python 2.6+
* numpy
* C++ compiler
* FORTRAN compiler

`Python(x,y) <http://code.google.com/p/pythonxy/>`_ is a great way to get all
of these if you are using windows and satisfied with 32bit.

Download the source files of scipydirect, unzip, and then execute::

    $ python setup.py install

You can test the installation by running the examples under the folder ``test/``.
Some of the examples require `matplotlib <http://matplotlib.org/>`_.
